/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.internal;

import com.net2plan.interfaces.networkDesign.NetPlan;
import com.net2plan.utils.Pair;
import java.io.Serializable;
import java.util.Comparator;

/**
 * Comparator for forwarding rules. First sort in ascending order of installed node 
 * identifier, then by demand identifier, and finally by link identifier.
 * 
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.3.0
 */
public class ForwardingRuleComparator implements Comparator<Pair<Long, Long>>, Serializable
{
	private final NetPlan netPlan;
	private final long layerId;
	
	/**
	 * Constructor.
	 * 
	 * @param netPlan Network design
	 * @since 0.3.0
	 */
	public ForwardingRuleComparator(NetPlan netPlan)
	{
		this(netPlan, netPlan.getLayerDefaultId());
	}
		
	/**
	 * Constructor.
	 * 
	 * @param netPlan Network design
	 * @param layerId Layer identifier
	 * @since 0.3.0
	 */
	public ForwardingRuleComparator(NetPlan netPlan, long layerId)
	{
		this.netPlan = netPlan;
		this.layerId = layerId;
	}
		
	@Override
	public int compare(Pair<Long, Long> o1, Pair<Long, Long> o2)
	{
		long nodeId1 = netPlan.getLinkOriginNode(layerId, o1.getSecond());
		long nodeId2 = netPlan.getLinkOriginNode(layerId, o2.getSecond());
		
		int compareNodes = Long.compare(nodeId1, nodeId2);
		if (compareNodes != 0) return compareNodes;

		int compareDemands = o1.getFirst().compareTo(o2.getFirst());
		if (compareDemands != 0) return compareDemands;
		
		int compareLinks = o1.getSecond().compareTo(o2.getSecond());
		return compareLinks;
	}
}