/*******************************************************************************
 * Copyright (c) 2013-2015 Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl.html
 *
 * Contributors:
 *     Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza - initial API and implementation
 ******************************************************************************/
package com.net2plan.io;

import com.net2plan.interfaces.networkDesign.NetPlan;
import com.net2plan.internal.Constants;
import com.net2plan.internal.plugins.IOFilter;
import com.net2plan.utils.Triple;
import java.io.File;
import java.util.EnumSet;
import java.util.List;

/**
 * Default IO filter for Net2Plan.
 *
 * @author Pablo Pavon-Marino, Jose-Luis Izquierdo-Zaragoza
 * @since 0.3.1
 */
public class IONet2Plan extends IOFilter
{
	private final static String TITLE = "Net2Plan";

	/**
	 * Default constructor.
	 *
	 * @since 0.3.1
	 */
	public IONet2Plan()
	{
		super(TITLE, EnumSet.allOf(Constants.IOFeature.class), "n2p");
	}

	@Override
	public String getName()
	{
		return TITLE + " import/export filter";
	}

	@Override
	public List<Triple<String, String, String>> getParameters()
	{
		return null;
	}

	@Override
	public int getPriority()
	{
		return Integer.MAX_VALUE;
	}

	@Override
	public NetPlan readDemandSetFromFile(File file)
	{
		NetPlan netPlan = readFromFile(file);
		netPlan = netPlan.getLayer(netPlan.getLayerDefaultId());
		netPlan.removeAllLinks();
		netPlan.removeAllRoutingInformation();
		netPlan.removeAllSRGs();

		return netPlan;
	}

	@Override
	public NetPlan readFromFile(File file)
	{
		return new NetPlan(file);
	}

	@Override
	public void saveDemandSetToFile(NetPlan netPlan, File file)
	{
		netPlan = netPlan.getLayer(netPlan.getLayerDefaultId());
		netPlan.removeAllLinks();
		netPlan.removeAllRoutingInformation();
		netPlan.removeAllSRGs();
		netPlan.saveToFile(file);
	}

	@Override
	public void saveToFile(NetPlan netPlan, File file)
	{
		netPlan.saveToFile(file);
	}
}